@@ -62,8 +62,7 @@ func ensurePodSpec(modified *bool, existing *corev1.PodSpec, required corev1.Pod
 }
 
 func ensureContainers(modified *bool, existing *[]corev1.Container, required []corev1.Container) {
-	for i := len(*existing) - 1; i >= 0; i-- {
-		existingContainer := &(*existing)[i]
+	for i, existingContainer := range *existing {
 		var existingCurr *corev1.Container
 		for _, requiredContainer := range required {
 			if existingContainer.Name == requiredContainer.Name {
@@ -104,7 +103,23 @@ func ensureContainer(modified *bool, existing *corev1.Container, required corev1
 	ensureEnvFromSource(modified, &existing.EnvFrom, required.EnvFrom)
 	setStringIfSet(modified, &existing.WorkingDir, required.WorkingDir)
 	ensureResourceRequirements(modified, &existing.Resources, required.Resources)
-	ensureContainerPorts(modified, &existing.Ports, required.Ports)
+
+	// any port we specify, we require
+	for _, required := range required.Ports {
+		var existingCurr *corev1.ContainerPort
+		for j, curr := range existing.Ports {
+			if curr.Name == required.Name {
+				existingCurr = &existing.Ports[j]
+				break
+			}
+		}
+		if existingCurr == nil {
+			*modified = true
+			existing.Ports = append(existing.Ports, corev1.ContainerPort{})
+			existingCurr = &existing.Ports[len(existing.Ports)-1]
+		}
+		ensureContainerPort(modified, existingCurr, required)
+	}
 
 	// any volume mount we specify, we require
 	for _, required := range required.VolumeMounts {
@@ -123,8 +138,12 @@ func ensureContainer(modified *bool, existing *corev1.Container, required corev1
 		ensureVolumeMount(modified, existingCurr, required)
 	}
 
-	ensureProbePtr(modified, &existing.LivenessProbe, required.LivenessProbe)
-	ensureProbePtr(modified, &existing.ReadinessProbe, required.ReadinessProbe)
+	if required.LivenessProbe != nil {
+		ensureProbePtr(modified, &existing.LivenessProbe, required.LivenessProbe)
+	}
+	if required.ReadinessProbe != nil {
+		ensureProbePtr(modified, &existing.ReadinessProbe, required.ReadinessProbe)
+	}
 
 	// our security context should always win
 	ensureSecurityContextPtr(modified, &existing.SecurityContext, required.SecurityContext)
@@ -151,10 +170,11 @@ func ensureEnvFromSource(modified *bool, existing *[]corev1.EnvFromSource, requi
 }
 
 func ensureProbePtr(modified *bool, existing **corev1.Probe, required *corev1.Probe) {
-	if *existing == nil && required == nil {
+	// if we have no required, then we don't care what someone else has set
+	if required == nil {
 		return
 	}
-	if *existing == nil || required == nil {
+	if *existing == nil {
 		*modified = true
 		*existing = required
 		return
@@ -175,14 +195,20 @@ func ensureProbeHandler(modified *bool, existing *corev1.Handler, required corev
 	}
 }
 
-func ensureContainerPorts(modified *bool, existing *[]corev1.ContainerPort, required []corev1.ContainerPort) {
-	for i := len(*existing) - 1; i >= 0; i-- {
-		existingContainerPort := &(*existing)[i]
-		var existingCurr *corev1.ContainerPort
-		for _, requiredContainerPort := range required {
-			if existingContainerPort.Name == requiredContainerPort.Name {
+func ensureContainerPort(modified *bool, existing *corev1.ContainerPort, required corev1.ContainerPort) {
+	if !equality.Semantic.DeepEqual(required, *existing) {
+		*modified = true
+		*existing = required
+	}
+}
+
+func EnsureServicePorts(modified *bool, existing *[]corev1.ServicePort, required []corev1.ServicePort) {
+	for i, existingServicePort := range *existing {
+		var existingCurr *corev1.ServicePort
+		for _, requiredServicePort := range required {
+			if existingServicePort.Name == requiredServicePort.Name {
 				existingCurr = &(*existing)[i]
-				ensureContainerPort(modified, existingCurr, requiredContainerPort)
+				ensureServicePort(modified, existingCurr, requiredServicePort)
 				break
 			}
 		}
@@ -191,28 +217,36 @@ func ensureContainerPorts(modified *bool, existing *[]corev1.ContainerPort, requ
 			*existing = append((*existing)[:i], (*existing)[i+1:]...)
 		}
 	}
-	for _, requiredContainerPort := range required {
+
+	for _, requiredServicePort := range required {
 		match := false
-		for _, existingContainerPort := range *existing {
-			if existingContainerPort.Name == requiredContainerPort.Name {
+		for _, existingServicePort := range *existing {
+			if existingServicePort.Name == requiredServicePort.Name {
 				match = true
 				break
 			}
 		}
 		if !match {
 			*modified = true
-			*existing = append(*existing, requiredContainerPort)
+			*existing = append(*existing, requiredServicePort)
 		}
 	}
 }
 
-func ensureContainerPort(modified *bool, existing *corev1.ContainerPort, required corev1.ContainerPort) {
+func ensureServicePort(modified *bool, existing *corev1.ServicePort, required corev1.ServicePort) {
+	ensureServicePortDefaults(&required)
 	if !equality.Semantic.DeepEqual(required, *existing) {
 		*modified = true
 		*existing = required
 	}
 }
 
+func ensureServicePortDefaults(servicePort *corev1.ServicePort) {
+	if servicePort.Protocol == "" {
+		servicePort.Protocol = corev1.ProtocolTCP
+	}
+}
+
 func ensureVolumeMount(modified *bool, existing *corev1.VolumeMount, required corev1.VolumeMount) {
 	if !equality.Semantic.DeepEqual(required, *existing) {
 		*modified = true
