@@ -10,7 +10,6 @@ import (
 	"github.com/davecgh/go-spew/spew"
 	"github.com/prometheus/client_golang/prometheus"
 	dto "github.com/prometheus/client_model/go"
-
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
@@ -345,6 +344,9 @@ func Test_operatorMetrics_Collect(t *testing.T) {
 								DesiredUpdate: &configv1.Update{Version: "1.0.0", Image: "test/image:2"},
 							},
 							Status: configv1.ClusterVersionStatus{
+								History: []configv1.UpdateHistory{
+									{State: configv1.CompletedUpdate, Version: "0.0.2", Image: "test/image:1", CompletionTime: &([]metav1.Time{{Time: time.Unix(2, 0)}}[0])},
+								},
 								Conditions: []configv1.ClusterOperatorStatusCondition{
 									{Type: ClusterStatusFailing, Status: configv1.ConditionTrue, LastTransitionTime: metav1.Time{Time: time.Unix(4, 0)}, Reason: "Because stuff"},
 								},
@@ -357,13 +359,13 @@ func Test_operatorMetrics_Collect(t *testing.T) {
 				if len(metrics) != 8 {
 					t.Fatalf("Unexpected metrics %s", spew.Sdump(metrics))
 				}
-				expectMetric(t, metrics[0], 5, map[string]string{"type": "initial", "version": "", "image": "", "from_version": ""})
-				expectMetric(t, metrics[1], 5, map[string]string{"type": "cluster", "version": "0.0.2", "image": "test/image:1", "from_version": ""})
-				expectMetric(t, metrics[2], 5, map[string]string{"type": "desired", "version": "1.0.0", "image": "test/image:2", "from_version": ""})
-				expectMetric(t, metrics[3], 4, map[string]string{"type": "failure", "version": "1.0.0", "image": "test/image:2", "from_version": ""})
-				expectMetric(t, metrics[4], 4, map[string]string{"type": "failure", "version": "0.0.2", "image": "test/image:1", "from_version": ""})
+				expectMetric(t, metrics[0], 2, map[string]string{"type": "completed", "version": "0.0.2", "image": "test/image:1", "from_version": ""})
+				expectMetric(t, metrics[1], 5, map[string]string{"type": "initial", "version": "0.0.2", "image": "test/image:1", "from_version": ""})
+				expectMetric(t, metrics[2], 5, map[string]string{"type": "cluster", "version": "0.0.2", "image": "test/image:1", "from_version": "0.0.2"})
+				expectMetric(t, metrics[3], 5, map[string]string{"type": "desired", "version": "1.0.0", "image": "test/image:2", "from_version": "0.0.2"})
+				expectMetric(t, metrics[4], 4, map[string]string{"type": "failure", "version": "1.0.0", "image": "test/image:2", "from_version": "0.0.2"})
 				expectMetric(t, metrics[5], 1, map[string]string{"name": "version", "condition": "Failing", "reason": "Because stuff"})
-				expectMetric(t, metrics[6], 6, map[string]string{"type": "current", "version": "0.0.2", "image": "test/image:1", "from_version": ""})
+				expectMetric(t, metrics[6], 6, map[string]string{"type": "current", "version": "0.0.2", "image": "test/image:1", "from_version": "0.0.2"})
 				expectMetric(t, metrics[7], 1, map[string]string{"type": ""})
 			},
 		},
@@ -407,10 +409,10 @@ func Test_operatorMetrics_Collect(t *testing.T) {
 				releaseVersion: "0.0.2",
 				releaseImage:   "test/image:1",
 				releaseCreated: time.Unix(3, 0),
-				cmLister: &cmLister{
+				cmConfigLister: &cmConfigLister{
 					Items: []*corev1.ConfigMap{{
 						ObjectMeta: metav1.ObjectMeta{Name: "openshift-install"},
-						Data: map[string]string {"version": "v0.0.2", "invoker": "jane"},
+						Data:       map[string]string{"version": "v0.0.2", "invoker": "jane"},
 					}},
 				},
 			},
@@ -428,7 +430,7 @@ func Test_operatorMetrics_Collect(t *testing.T) {
 				releaseVersion: "0.0.2",
 				releaseImage:   "test/image:1",
 				releaseCreated: time.Unix(3, 0),
-				cmLister: &cmLister{
+				cmConfigLister: &cmConfigLister{
 					Items: []*corev1.ConfigMap{{
 						ObjectMeta: metav1.ObjectMeta{Name: "openshift-install"},
 					}},
@@ -448,7 +450,7 @@ func Test_operatorMetrics_Collect(t *testing.T) {
 				releaseVersion: "0.0.2",
 				releaseImage:   "test/image:1",
 				releaseCreated: time.Unix(3, 0),
-				cmLister: &cmLister{
+				cmConfigLister: &cmConfigLister{
 					Err: errors.New("dial timeout"),
 				},
 			},
@@ -468,8 +470,8 @@ func Test_operatorMetrics_Collect(t *testing.T) {
 			if tt.optr.coLister == nil {
 				tt.optr.coLister = &coLister{}
 			}
-			if tt.optr.cmLister == nil {
-				tt.optr.cmLister = &cmLister{}
+			if tt.optr.cmConfigLister == nil {
+				tt.optr.cmConfigLister = &cmConfigLister{}
 			}
 			m := newOperatorMetrics(tt.optr)
 			descCh := make(chan *prometheus.Desc)
@@ -564,8 +566,8 @@ func Test_operatorMetrics_CollectTransitions(t *testing.T) {
 			if tt.optr.coLister == nil {
 				tt.optr.coLister = &coLister{}
 			}
-			if tt.optr.cmLister == nil {
-				tt.optr.cmLister = &cmLister{}
+			if tt.optr.cmConfigLister == nil {
+				tt.optr.cmConfigLister = &cmConfigLister{}
 			}
 			m := newOperatorMetrics(tt.optr)
 			for i := range tt.changes {
